//
//  XXYCoreKitApi.h
//  XXYSDKCoreKit
//
//  Created by nickey on 2020/12/15.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

#define XXY_CORE_SDK_VERSION @"2.0.3.2"

NS_ASSUME_NONNULL_BEGIN
@protocol XXYCoreKitDelegate <NSObject>

/// 初始化成功回调
- (void)initSuccess;

/// 登录成功回调
/// @param uid 返回的用户id
/// @param uname 返回的用户名字
- (void)loginSuccess:(NSString *)uid uname:(NSString *)uname;

/// 关闭登录框回调
- (void)loginClose;

/// 退出登录回调
- (void)exitLogin;

/// 上传角色回调
- (void)uploadRoleSuccess;

/// 切换小号回调
/// @param uid 返回的新用户id
/// @param uname 返回的用户名字
- (void)changeAccount:(NSString *)uid uname:(NSString *)uname muid:(NSString *)muid;

/// 注册回调
/// @param uid 返回的用户id
/// @param uname 返回的用户名字
- (void)regSuccess:(NSString *)uid uname:(NSString *)uname;


//––––––––––––––––  add by 2022.12.27
/// 订单信息
/// @param orderInfoDic 订单信息字典
/// orderInfoDic 内容:
/// order 平台订单号
/// gorder 游戏方订单号
/// status 充值状态（成功、失败/取消）
/// gname 游戏名称
/// sname 游戏服名称
/// other 充值其他（订单其他数据）
- (void)orderInfoResult:(NSDictionary *)orderInfoDic;
//––––––––––––––––


//––––––––––––––––  add by 2023.10.24
/// 用户从支付页面返回游戏
/// @param userId 用户ID
- (void)orderCancelByUserId:(NSString *)userId;
//––––––––––––––––
@end

@interface XXYCoreKitApi : NSObject

/// XXYCoreKitDelegate
@property (nonatomic, weak) id <XXYCoreKitDelegate> delegate;

/// SDK接口单例
+ (XXYCoreKitApi *)sharedInstance;


-(void)changeBaseUrl:(NSString *)url basePid:(NSString *)pid baseKey:(NSString*)key public_key:(NSString *)publicKey;
/// 初始化SDK
/// 应用启动时调用
/// @param pid 游戏pid账号
/// @param gid 游戏初始化时返回的游戏编号
/// @param extra 透传参数（非必传参数）
+ (void)initSDK:(nonnull NSString *)pid Gid:(nonnull NSString *)gid Extra:(NSString *)extra;


////展示个人信息保护引导协议
//+ (void)showPersonalInfoProtectionView;

/// 显示登陆页面
+ (void)showLogin;


/// 角色上报
/// @param uid 用户编号
/// @param mUid 小号id（非必传参数）
/// @param gameSid 游戏方的游戏服id
/// @param roleNumber 角色编号
/// @param roleName 角色名称
/// @param roleLevel 角色等级
/// @param roleProfessional 职业（非必传参数）
/// @param roleConversion 转生次数（非必传参数）
/// @param roleFighting 战斗力（非必传参数）
/// @param roleExp 经验值（非必传参数）
/// @param roleSex 性别（非必传参数）
/// @param roleCoins 金币（非必传参数）
/// @param roleMoney 角色金额（非必传参数）
/// @param roleCreateTime 角色创建时间（非必传参数；时间戳格式）
/// @param roleData 角色json（非必传参数；json字符串格式）
+ (void)uploadRoleWithUid:(nonnull NSString *)uid MUid:(NSString *)mUid GameSid:(nonnull NSString *)gameSid RoleNumber:(nonnull NSString *)roleNumber RoleName:(nonnull NSString *)roleName RoleLevel:(nonnull NSString *)roleLevel RoleProfessional:(NSString *)roleProfessional RoleConversion:(NSString *)roleConversion RoleFighting:(NSString *)roleFighting RoleExp:(NSString *)roleExp RoleSex:(NSString *)roleSex RoleCoins:(NSString *)roleCoins RoleMoney:(NSString *)roleMoney RoleCreateTime:(NSString *)roleCreateTime RoleData:(NSString *)roleData;

/// 显示支付界面
/// @param gameSid 游戏的游戏服编号
/// @param roleName 游戏角色名称
/// @param roleNumber 角色编号
/// @param money 游戏支付金额
/// @param other 游戏生成的订单号
+ (void)showPaySid:(nonnull NSString *)gameSid roleName:(nonnull NSString *)roleName roleNumber:(nonnull NSString *)roleNumber money:(double)money other:(nullable NSString *)other;

/// 显示小球
+ (void)showBall;

/// 关闭小球
+ (void)hidenBall;

/// 退出登陆
+ (void)exitLogin;

/// 设置日志是否输出
/// @param enable 开关设置BOOL值，默认为NO
+ (void)setLogEnable:(BOOL)enable;

/// 获取实名认证状态
/// @param block 状态回调 YES:已实名 NO:未实名
+ (void)getVerifiedStatus:(void (^)(BOOL status))block;

/// 获取实名信息
/// @param type 获取内容type（0：名字 1：身份证号 2：年龄）
/// @param block 回调信息
+ (void)getRealNameOrIdCardOrAgeWithType:(int)type Block:(void (^)(NSString *info))block;

/// 显示实名认证弹窗
/// @param isForcibly 是否强制实名认证（YES:强制认证，隐藏关闭弹窗按钮 NO:不强制认证，显示关闭弹窗按钮）
+ (void)showRealNameAuthenticationView:(BOOL)isForcibly;

/**
 * 应用事件
 */
- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(NSString *)sourceApplication annotation:(id)annotation;
// NOTE: 9.0以后使用新API接口
- (BOOL)application:(UIApplication *)app openURL:(NSURL *)url options:(NSDictionary<NSString*, id> *)options;

- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url;

- (BOOL)application:(UIApplication *)application continueUserActivity:(NSUserActivity *)userActivity restorationHandler:(void(^)(NSArray<id<UIUserActivityRestoring>> * __nullable restorableObjects))restorationHandler;
@end

NS_ASSUME_NONNULL_END
